@@ -1,11 +1,15 @@
 import collections
-from datetime import datetime
+from functools import reduce
 
 from django import template
+from django.utils import timezone
+from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 
-from ephios.core.models import AbstractParticipation, LocalParticipation
+from ephios.core.models import AbstractParticipation, EventType, LocalParticipation
+from ephios.core.signals import register_event_bulk_action
 from ephios.core.views.signup import request_to_participant
+from ephios.extra.colors import get_eventtype_color_style
 
 register = template.Library()
 
@@ -59,7 +63,7 @@ def decline_errors(request, shift):
 def confirmed_shifts(user):
     return (
         user.get_shifts(with_participation_state_in=[AbstractParticipation.States.CONFIRMED])
-        .filter(end_time__gte=datetime.now())
+        .filter(end_time__gte=timezone.now())
         .order_by("start_time")
     )
 
@@ -77,3 +81,32 @@ def event_signup_state_counts(event, user):
                 counter[participation.state] += 1
                 break
     return counter
+
+
+@register.simple_tag(name="event_bulk_actions")
+def event_bulk_actions():
+    html = ""
+    for _, actions in register_event_bulk_action.send(None):
+        html += "".join(
+            [
+                f"<button class='btn btn-secondary mr-1' type='submit' name='{action['url']}' formaction='{action['url']}'><span class='fa {action['icon']}'></span> {action['label']}</button>"
+                for action in actions
+            ]
+        )
+    return format_html(html)
+
+
+@register.simple_tag(name="eventtype_colors")
+def eventtype_colors():
+    return mark_safe(
+        reduce(
+            lambda css, eventtype: css + get_eventtype_color_style(eventtype),
+            EventType.objects.all(),
+            "",
+        )
+    )
+
+
+@register.filter(name="color_css")
+def eventtype_color_css(eventtype):
+    return get_eventtype_color_style(eventtype)
